==> navigation_plus-1.0.7.tar.gz: navigation_plus/js/navigation_plus/top-bar.js <==
(($, Drupal, once) => {

  /**
   * Refresh button.
   */
  Drupal.behaviors.NavigationPlusRefresh = {
    attach: (context, settings) => {
      once('NavigationPlusRefresh', '#navigation-plus-refresh', context).forEach(refreshButton => {
        refreshButton.onclick = (e) => {
          location.reload();
        }
      });
    }
  };

  /**
   * Save button
   */
  Drupal.behaviors.NavigationPlusSave = {
    attach: (context, settings) => {
      once('NavigationPlusSave', '#navigation-plus-save', context).forEach(saveButton => {

        saveButton.onclick = (e) => {
          // @todo Temporarily use the edit+ save controller.
          // @todo This creates a dependency on edit+ when in reality the
          // @todo tempstore for edit+ and LB+ should bubble up to some parent
          // @todo module.
          const editMode = Drupal.NavigationPlus.ModeManager.getPlugin('edit');
          const entityWrapperId = editMode.getMainEntityWrapper().dataset.navigationPlusEntityWrapper;
          const parts = entityWrapperId.split('::');

          window.location = Drupal.url('edit-plus/tempstore/save/' + parts[0] + '.' + parts[1]+ '?destination=' + window.location.pathname);
        }
      });
    }
  };

  /**
   * Discard changes button
   */
  Drupal.behaviors.NavigationPlusDiscardChanges = {
    attach: (context, settings) => {
      once('NavigationPlusDiscardChanges', '#navigation-plus-discard-changes', context).forEach(discardChangesButton => {

        discardChangesButton.onclick = (e) => {
          // @todo Temporarily use the edit+ save controller.
          // @todo This creates a dependency on edit+ when in reality the
          // @todo tempstore for edit+ and LB+ should bubble up to some parent
          // @todo module.
          const editMode = Drupal.NavigationPlus.ModeManager.getPlugin('edit');
          const entityWrapperId = editMode.getMainEntityWrapper().dataset.navigationPlusEntityWrapper;
          const parts = entityWrapperId.split('::');
          Drupal.NavigationPlus.ModePluginBase.ajax({
            url: Drupal.url('edit-plus/tempstore/delete-confirm/' + parts[0] + '.' + parts[1]+ '?destination=' + window.location.pathname),
            dialogType: 'modal',
            dialog: {
              title: Drupal.t('Discard changes?'),
              width: 'auto',
              height: 'auto',
              dialogClass: 'discard-changes-dialog',
            },
          }).execute();
        }
      });
    }
  };

})(jQuery, Drupal, once);

==> navigation_plus-1.0.23.tar.gz: navigation_plus/js/navigation_plus/top-bar.js <==
(($, Drupal, once) => {

  /**
   * Refresh button.
   */
  Drupal.behaviors.NavigationPlusRefresh = {
    attach: (context, settings) => {
      once('NavigationPlusRefresh', '#navigation-plus-refresh', context).forEach(refreshButton => {
        refreshButton.onclick = (e) => {
          location.reload();
        }
      });
    }
  };

  /**
   * Save button
   */
  Drupal.behaviors.NavigationPlusSave = {
    attach: (context, settings) => {
      once('NavigationPlusSave', '#navigation-plus-save', context).forEach(saveButton => {

        saveButton.onclick = async (e) => {
          if (Drupal.EditPlus) {
            await Drupal.EditPlus.notUpdating();
          }
          // @todo Temporarily use the edit+ save controller.
          // @todo This creates a dependency on edit+ when in reality the
          // @todo tempstore for edit+ and LB+ should bubble up to some parent
          // @todo module.
          const editMode = Drupal.NavigationPlus.ModeManager.getPlugin('edit');
          const entityWrapperId = editMode.getMainEntityWrapper().dataset.navigationPlusEntityWrapper;
          const parts = entityWrapperId.split('::');

          window.location = Drupal.url('edit-plus/tempstore/save/' + parts[0] + '.' + parts[1]+ '?destination=' + window.location.pathname);
        }
      });
    }
  };

  /**
   * Discard changes button
   */
  Drupal.behaviors.NavigationPlusDiscardChanges = {
    attach: (context, settings) => {
      once('NavigationPlusDiscardChanges', '#navigation-plus-discard-changes', context).forEach(discardChangesButton => {

        discardChangesButton.onclick = (e) => {
          // @todo Temporarily use the edit+ save controller.
          // @todo This creates a dependency on edit+ when in reality the
          // @todo tempstore for edit+ and LB+ should bubble up to some parent
          // @todo module.
          const editMode = Drupal.NavigationPlus.ModeManager.getPlugin('edit');
          const entityWrapperId = editMode.getMainEntityWrapper().dataset.navigationPlusEntityWrapper;
          const parts = entityWrapperId.split('::');
          Drupal.NavigationPlus.ModePluginBase.ajax({
            url: Drupal.url('edit-plus/tempstore/delete-confirm/' + parts[0] + '.' + parts[1]+ '?destination=' + window.location.pathname),
            dialogType: 'modal',
            dialog: {
              title: Drupal.t('Discard changes?'),
              width: 'auto',
              height: 'auto',
              dialogClass: 'discard-changes-dialog',
            },
          }).execute();
        }
      });
    }
  };

})(jQuery, Drupal, once);
